"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CeidgApiClient = void 0;
const request_promise_native_1 = __importDefault(require("request-promise-native"));
const ceidgModel_1 = require("./models/ceidgModel");
const RestResponse_1 = require("./models/RestResponse");
const html_entities_1 = require("html-entities");
const ResponseAddressData_1 = require("./models/RestResponse/ResponseAddressData");
const ResponseLegalForm_1 = require("./models/RestResponse/ResponseLegalForm");
class CeidgApiClient {
    constructor() {
        this.baseUrl = 'https://dane.biznes.gov.pl';
    }
    // constructor(token: string) {
    //     this.baseUrl = baseUrl;
    // }
    generateResponse(data) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r;
            const response = new RestResponse_1.RestResponse();
            response.source = 'CEIDG';
            const ceidgData = data.firma; // data.firma.find(u => u.status.toLocaleLowerCase() === 'aktywny')[0];
            // if (!ceidgData) {
            //     ceidgData = this.getLatestFirma(data);
            // }
            if (ceidgData) {
                response.nip = ceidgData.wlasciciel.nip;
                response.regon = ceidgData.wlasciciel.regon;
                response.companyName = html_entities_1.XmlEntities.decode(ceidgData.nazwa || '').replace(/\s+/g, ' ').trim();
                response.startDate = ceidgData.dataRozpoczecia || '';
                response.endDate = ceidgData.dataWykreslenia || '';
                response.status = ceidgData.status.toUpperCase() || '';
                response.phone = '';
                response.email = ceidgData.email || '';
                response.website = ceidgData.www || '';
                response.pkd = ceidgData.pkd ? ceidgData.pkd.toLocaleString().split(',') : [];
                response.legalForm = new ResponseLegalForm_1.ResponseLegalForm();
                response.legalForm.basic = '';
                response.legalForm.specific = '';
                response.businessAddress = new ResponseAddressData_1.ResponseAddressData();
                response.businessAddress.town = ((_a = ceidgData.adresDzialalnosci) === null || _a === void 0 ? void 0 : _a.miasto) || '';
                response.businessAddress.zipCode = ((_b = ceidgData.adresDzialalnosci) === null || _b === void 0 ? void 0 : _b.kod) || '';
                response.businessAddress.street = ((_c = ceidgData.adresDzialalnosci) === null || _c === void 0 ? void 0 : _c.ulica) || '';
                response.businessAddress.houseNo = ((_d = ceidgData.adresDzialalnosci) === null || _d === void 0 ? void 0 : _d.budynek) || '';
                response.businessAddress.doorNo = ((_e = ceidgData.adresDzialalnosci) === null || _e === void 0 ? void 0 : _e.lokal) || '';
                response.businessAddress.post = '';
                response.businessAddress.community = ((_f = ceidgData.adresDzialalnosci) === null || _f === void 0 ? void 0 : _f.gmina) || '';
                response.businessAddress.county = ((_g = ceidgData.adresDzialalnosci) === null || _g === void 0 ? void 0 : _g.powiat) || '';
                response.businessAddress.province = ((_h = ceidgData.adresDzialalnosci) === null || _h === void 0 ? void 0 : _h.wojewodztwo) || '';
                response.correspondenceAddress = new ResponseAddressData_1.ResponseAddressData();
                response.correspondenceAddress.town = ((_j = ceidgData.adresKorespondencyjny) === null || _j === void 0 ? void 0 : _j.miasto) || '';
                response.correspondenceAddress.zipCode = ((_k = ceidgData.adresKorespondencyjny) === null || _k === void 0 ? void 0 : _k.kod) || '';
                response.correspondenceAddress.street = ((_l = ceidgData.adresKorespondencyjny) === null || _l === void 0 ? void 0 : _l.ulica) || '';
                response.correspondenceAddress.houseNo = ((_m = ceidgData.adresKorespondencyjny) === null || _m === void 0 ? void 0 : _m.budynek) || '';
                response.correspondenceAddress.doorNo = ((_o = ceidgData.adresKorespondencyjny) === null || _o === void 0 ? void 0 : _o.lokal) || '';
                response.correspondenceAddress.post = '';
                response.correspondenceAddress.community = ((_p = ceidgData.adresKorespondencyjny) === null || _p === void 0 ? void 0 : _p.gmina) || '';
                response.correspondenceAddress.county = ((_q = ceidgData.adresKorespondencyjny) === null || _q === void 0 ? void 0 : _q.powiat) || '';
                response.correspondenceAddress.province = ((_r = ceidgData.adresKorespondencyjny) === null || _r === void 0 ? void 0 : _r.wojewodztwo) || '';
            }
            return response;
        });
    }
    // // Funkcja do wyciągnięcia firmy z najnowszą datą rozpoczęcia
    // public getLatestFirma = (data: any) => {
    //     return data.firma
    //         .sort(
    //             (a: { dataRozpoczecia: string }, b: { dataRozpoczecia: string }) =>
    //                 new Date(b.dataRozpoczecia).getTime() - new Date(a.dataRozpoczecia).getTime()
    //         )[0];
    // };
    getDataByNip(token, nipNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = {
                url: `${this.baseUrl}/api/ceidg/v2/firma?nip=${nipNumber}`,
                method: 'GET',
                headers: {
                    Authorization: `Bearer ${token}`,
                },
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                // console.log(resultBody);
                if (resultBody) {
                    return ceidgModel_1.CeidgModel.fromJson(resultBody);
                }
            }
            catch (error) {
                throw new Error(`Failed (CEIDG) to fetch user with nip number ${nipNumber}: ${error}`);
            }
        });
    }
}
exports.CeidgApiClient = CeidgApiClient;
