"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GusApiClient = void 0;
const request_promise_native_1 = __importDefault(require("request-promise-native"));
const gusModel_1 = require("./models/gusModel");
const ReportRequest_1 = require("./models/GUS/ReportRequest");
const RestResponse_1 = require("./models/RestResponse");
const html_entities_1 = require("html-entities");
const ResponseLegalForm_1 = require("./models/RestResponse/ResponseLegalForm");
const ResponseAddressData_1 = require("./models/RestResponse/ResponseAddressData");
class GusApiClient {
    constructor() {
        this.baseUrl = 'https://wyszukiwarkaregon.stat.gov.pl/wsBIR/UslugaBIRzewnPubl.svc';
    }
    generateResponse(dataGus, nip) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = new RestResponse_1.RestResponse();
            response.source = 'GUS';
            response.nip = dataGus.dane.praw_nip || '';
            response.regon = dataGus.dane.praw_regon9 || '';
            response.krs = dataGus.dane.praw_numerWRejestrzeEwidencji || '';
            response.companyName = html_entities_1.XmlEntities.decode(dataGus.dane.praw_nazwa || '').replace(/\s+/g, ' ').trim();
            response.startDate = dataGus.dane.praw_dataRozpoczeciaDzialalnosci || '';
            response.endDate = dataGus.dane.praw_dataZakonczeniaDzialalnosci || '';
            response.status = dataGus.dane.praw_dataZakonczeniaDzialalnosci ? 'WYKREŚLONY' : 'AKTYWNY';
            response.phone = dataGus.dane.praw_numerTelefonu || '';
            response.email = dataGus.dane.praw_adresEmail || '';
            response.website = dataGus.dane.praw_adresStronyinternetowej || '';
            response.pkd = dataGus.dane.pkd;
            response.legalForm = new ResponseLegalForm_1.ResponseLegalForm();
            response.legalForm.basic = dataGus.dane.praw_podstawowaFormaPrawna_Symbol || '';
            response.legalForm.specific = dataGus.dane.praw_szczegolnaFormaPrawna_Symbol || '';
            response.businessAddress = new ResponseAddressData_1.ResponseAddressData();
            response.businessAddress.town = dataGus.dane.praw_adSiedzMiejscowosc_Nazwa || '';
            response.businessAddress.zipCode = dataGus.dane.praw_adSiedzKodPocztowy || '';
            response.businessAddress.street = dataGus.dane.praw_adSiedzUlica_Nazwa || '';
            response.businessAddress.houseNo = dataGus.dane.praw_adSiedzNumerNieruchomosci || '';
            response.businessAddress.doorNo = dataGus.dane.praw_adSiedzNumerLokalu || '';
            response.businessAddress.post = dataGus.dane.praw_adSiedzMiejscowoscPoczty_Nazwa || '';
            response.businessAddress.community = dataGus.dane.praw_adSiedzGmina_Nazwa || '';
            response.businessAddress.county = dataGus.dane.praw_adSiedzPowiat_Nazwa || '';
            response.businessAddress.province = dataGus.dane.praw_adSiedzWojewodztwo_Nazwa || '';
            response.correspondenceAddress = new ResponseAddressData_1.ResponseAddressData();
            response.correspondenceAddress.town = '';
            response.correspondenceAddress.zipCode = '';
            response.correspondenceAddress.street = '';
            response.correspondenceAddress.houseNo = '';
            response.correspondenceAddress.doorNo = '';
            response.correspondenceAddress.post = '';
            response.correspondenceAddress.community = '';
            response.correspondenceAddress.county = '';
            response.correspondenceAddress.province = '';
            if (response.nip === '') {
                response.nip = nip;
                response.status = 'WYKRESLONY';
                response.pkd = [];
            }
            return response;
        });
    }
    generateResponseSimple(dataGusSimple) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = new RestResponse_1.RestResponse();
            response.source = 'GUS';
            response.nip = dataGusSimple.dane[0].Nip || '';
            response.regon = dataGusSimple.dane[0].Regon || '';
            response.krs = '';
            response.companyName = html_entities_1.XmlEntities.decode(dataGusSimple.dane[0].Nazwa || '').replace(/\s+/g, ' ').trim();
            ;
            response.startDate = '';
            response.endDate = dataGusSimple.dane[0].DataZakonczeniaDzialalnosci || '';
            response.status = 'WYKRESLONY';
            response.phone = '';
            response.email = '';
            response.website = '';
            response.pkd = [];
            response.legalForm = new ResponseLegalForm_1.ResponseLegalForm();
            response.legalForm.basic = '';
            response.legalForm.specific = '';
            response.businessAddress = new ResponseAddressData_1.ResponseAddressData();
            response.businessAddress.town = dataGusSimple.dane[0].Miejscowosc || '';
            response.businessAddress.zipCode = dataGusSimple.dane[0].KodPocztowy || '';
            response.businessAddress.street = dataGusSimple.dane[0].Ulica || '';
            response.businessAddress.houseNo = dataGusSimple.dane[0].NrNieruchomosci.toString() || '';
            response.businessAddress.doorNo = dataGusSimple.dane[0].NrLokalu || '';
            response.businessAddress.post = dataGusSimple.dane[0].MiejscowoscPoczty || '';
            response.businessAddress.community = dataGusSimple.dane[0].Gmina || '';
            response.businessAddress.county = dataGusSimple.dane[0].Powiat || '';
            response.businessAddress.province = dataGusSimple.dane[0].Wojewodztwo || '';
            response.correspondenceAddress = new ResponseAddressData_1.ResponseAddressData();
            response.correspondenceAddress.town = '';
            response.correspondenceAddress.zipCode = '';
            response.correspondenceAddress.street = '';
            response.correspondenceAddress.houseNo = '';
            response.correspondenceAddress.doorNo = '';
            response.correspondenceAddress.post = '';
            response.correspondenceAddress.community = '';
            response.correspondenceAddress.county = '';
            response.correspondenceAddress.province = '';
            return response;
        });
    }
    generateSessionIdentifier(requestSid) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = {
                method: 'POST',
                url: this.baseUrl,
                headers: {
                    'Content-Type': 'application/soap+xml;charset=UTF-8',
                },
                secureProtocol: 'TLSv1_2_method',
                body: requestSid.toXML(),
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                const sid = gusModel_1.GusModel.sidFromJson(resultBody);
                return sid;
            }
            catch (error) {
                throw new Error(`Failed to fetch Gus sid with apiKey ${requestSid.pKluczUzytkownika}: ${error}`);
            }
        });
    }
    simpleReport(sid, type, num) {
        return __awaiter(this, void 0, void 0, function* () {
            num = num.replace(/\D/g, '');
            const simplGusReportRequest = new ReportRequest_1.ReportRequest(num);
            const options = {
                method: 'POST',
                url: this.baseUrl,
                headers: {
                    'Content-Type': 'application/soap+xml',
                    sid: `${sid}`,
                },
                secureProtocol: 'TLSv1_2_method',
                body: simplGusReportRequest.toXML('simple'),
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                const simpleReportData = gusModel_1.GusModel.regonFromJson(resultBody);
                return simpleReportData;
            }
            catch (error) {
                throw new Error(`Failed to (GUS->Simple) fetch gus data with nip number ${num}: ${error}`);
            }
        });
    }
    fullReport(sid, regon, reportName) {
        return __awaiter(this, void 0, void 0, function* () {
            const fullGusReportRequest = new ReportRequest_1.ReportRequest('', regon, reportName);
            const options = {
                method: 'POST',
                url: this.baseUrl,
                headers: {
                    'Content-Type': 'application/soap+xml',
                    sid: `${sid}`,
                },
                secureProtocol: 'TLSv1_2_method',
                body: fullGusReportRequest.toXML('full'),
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                const result = gusModel_1.GusModel.fromJson(resultBody);
                if (result) {
                    result.dane.pkd = yield this.fullReportPkd(sid, regon, 'BIR11OsPrawnaPkd');
                }
                return result;
            }
            catch (error) {
                throw new Error(`Failed to fetch gus data with regon number ${regon}: ${error}`);
            }
        });
    }
    fullReportPkd(sid, regon, reportName) {
        return __awaiter(this, void 0, void 0, function* () {
            const fullGusReportRequest = new ReportRequest_1.ReportRequest('', regon, reportName);
            const options = {
                method: 'POST',
                url: this.baseUrl,
                headers: {
                    'Content-Type': 'application/soap+xml',
                    sid: `${sid}`,
                },
                secureProtocol: 'TLSv1_2_method',
                body: fullGusReportRequest.toXML('full'),
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                return gusModel_1.GusModel.fromJsonPkd(resultBody);
            }
            catch (error) {
                throw new Error(`Failed to fetch gus data with regon number ${regon}: ${error}`);
            }
        });
    }
}
exports.GusApiClient = GusApiClient;
