"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CeidgCheckerSingle = exports.CeidgChecker = void 0;
const ceidgApiClient_1 = require("./ceidgApiClient");
const gusApiClient_1 = require("./gusApiClient");
const krsApiClient_1 = require("./krsApiClient");
const gusModel_1 = require("./models/gusModel");
const CeidgChecker = (gusApiKey, ceidgToken, nip) => __awaiter(void 0, void 0, void 0, function* () {
    // Create the GUS SOAP request
    const gusRequestData = new gusModel_1.GusModel(gusApiKey);
    const gusApiClient = new gusApiClient_1.GusApiClient();
    const gusSid = yield gusApiClient.generateSessionIdentifier(gusRequestData.requestSid);
    console.log(`SID: ${gusSid}`);
    if (gusSid !== '') {
        console.log(`NIP: ${nip} -> GUS -> Simple Report`);
        const gusRegonData = yield gusApiClient.simpleReport(gusSid, 'nip', nip);
        if (gusRegonData) {
            if (gusRegonData.dane[0].Typ === 'F') {
                console.log(`Regon: ${gusRegonData === null || gusRegonData === void 0 ? void 0 : gusRegonData.dane[0].Regon} -> CEIDG -> Report`);
                const ceidgApiClient = new ceidgApiClient_1.CeidgApiClient();
                const ceidgData = yield ceidgApiClient.getDataByNip(ceidgToken, nip);
                if (ceidgData) {
                    return yield ceidgApiClient.generateResponse(ceidgData);
                }
                else {
                    console.log(`Regon: ${gusRegonData === null || gusRegonData === void 0 ? void 0 : gusRegonData.dane[0].Regon} -> CEIDG -> No data`);
                    const gusRegonDataExt = yield gusApiClient.fullReport(gusSid, gusRegonData.dane[0].Regon, 'BIR11OsFizyczna');
                    const gusRegonDataExtPkd = yield gusApiClient.fullReportPkd(gusSid, gusRegonData.dane[0].Regon, 'BIR11OsFizycznaPkd');
                    if (gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.ErrorCode) {
                        return yield gusApiClient.generateResponseSimple(gusRegonData);
                    }
                    if ((gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane) && gusRegonDataExtPkd) {
                        gusRegonDataExt.dane.pkd = gusRegonDataExtPkd;
                    }
                    if (gusRegonDataExt) {
                        return yield gusApiClient.generateResponse(gusRegonDataExt, nip);
                    }
                }
            }
            console.log(`Regon: ${gusRegonData === null || gusRegonData === void 0 ? void 0 : gusRegonData.dane[0].Regon} -> GUS -> Full Report`);
            const gusRegonDataExt = yield gusApiClient.fullReport(gusSid, gusRegonData.dane[0].Regon, 'BIR11OsPrawna');
            // console.log(gusRegonDataExt);
            const gusRegonDataExtPkd = yield gusApiClient.fullReportPkd(gusSid, gusRegonData.dane[0].Regon, 'BIR11OsPrawnaPkd');
            if ((gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji) && isStringNumber(gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji)) {
                console.log(`Rejestr Ewidencji: ${gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji} -> GUS -> KRS Report`);
                if (gusRegonDataExtPkd) {
                    gusRegonDataExt.dane.pkd = gusRegonDataExtPkd;
                }
                const krsApiClient = new krsApiClient_1.KrsApiClient();
                let krsData = yield krsApiClient.getDataByKrsNumber(gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji, 'P');
                if (!krsData) {
                    krsData = yield krsApiClient.getDataByKrsNumber(gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji, 'S');
                }
                if (krsData) {
                    return yield krsApiClient.generateResponse(krsData, gusRegonDataExt);
                }
            }
            if (gusRegonDataExt) {
                return yield gusApiClient.generateResponse(gusRegonDataExt, nip);
            }
        }
    }
});
exports.CeidgChecker = CeidgChecker;
const CeidgCheckerSingle = (checkType, token, nip) => __awaiter(void 0, void 0, void 0, function* () {
    if (checkType.toLocaleLowerCase() === 'gus') {
        // Create the GUS SOAP request
        const gusRequestData = new gusModel_1.GusModel(token);
        const gusApiClient = new gusApiClient_1.GusApiClient();
        const gusSid = yield gusApiClient.generateSessionIdentifier(gusRequestData.requestSid);
        console.log(`SID: ${gusSid}`);
        if (gusSid !== '') {
            console.log(`NIP: ${nip} -> GUS -> Simple Report`);
            const gusRegonData = yield gusApiClient.simpleReport(gusSid, 'nip', nip);
            if (gusRegonData && gusRegonData.dane[0].Typ !== 'F' && (gusRegonData === null || gusRegonData === void 0 ? void 0 : gusRegonData.dane[0].Regon)) {
                console.log(`Regon: ${gusRegonData === null || gusRegonData === void 0 ? void 0 : gusRegonData.dane[0].Regon} -> GUS -> Full Report`);
                const gusRegonDataExt = yield gusApiClient.fullReport(gusSid, gusRegonData.dane[0].Regon, 'BIR11OsPrawna');
                if (gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji) {
                    console.log(`Rejestr Ewidencji: ${gusRegonDataExt === null || gusRegonDataExt === void 0 ? void 0 : gusRegonDataExt.dane.praw_numerWRejestrzeEwidencji} -> GUS -> KRS Report`);
                    return yield gusApiClient.generateResponse(gusRegonDataExt, nip);
                }
            }
        }
    }
    if (checkType.toLocaleLowerCase() === 'ceidg') {
        const ceidgApiClient = new ceidgApiClient_1.CeidgApiClient();
        const ceidgData = yield ceidgApiClient.getDataByNip(token, nip);
        if (ceidgData) {
            return yield ceidgApiClient.generateResponse(ceidgData);
        }
    }
});
exports.CeidgCheckerSingle = CeidgCheckerSingle;
const isStringNumber = (value) => {
    return !isNaN(parseFloat(value)) && isFinite(value);
};
