"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KrsApiClient = void 0;
const request_promise_native_1 = __importDefault(require("request-promise-native"));
const krsModel_1 = require("./models/krsModel");
const RestResponse_1 = require("./models/RestResponse");
const html_entities_1 = require("html-entities");
const ResponseLegalForm_1 = require("./models/RestResponse/ResponseLegalForm");
const ResponseAddressData_1 = require("./models/RestResponse/ResponseAddressData");
class KrsApiClient {
    constructor() {
        this.baseUrl = 'https://api-krs.ms.gov.pl/api/krs/OdpisAktualny'; // {krs}?rejestr={rejestr}&format=json'
    }
    getDataByKrsNumber(krsNumber, rejestrFlag) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = {
                method: 'GET',
                url: `${this.baseUrl}/${krsNumber}?rejestr=${rejestrFlag}&format=json`,
                json: true,
                resolveWithFullResponse: true,
            };
            try {
                const resultBody = yield (0, request_promise_native_1.default)(options, (error, response) => {
                    return response.body;
                });
                if (!resultBody.body.odpis)
                    return undefined;
                if (resultBody)
                    return krsModel_1.KrsModel.fromJson(resultBody.body.odpis);
            }
            catch (error) {
                return undefined;
            }
            return undefined;
        });
    }
    formatDate(input) {
        const [day, month, year] = input.split('.');
        return `${year}-${month}-${day}`;
    }
    generateResponse(dataKrs, dataGus) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = new RestResponse_1.RestResponse();
            response.source = 'KRS';
            response.nip = dataKrs.dane.dzial1.danePodmiotu.identyfikatory.nip;
            response.regon = dataGus.dane.praw_regon9;
            response.krs = dataKrs.naglowekA.numerKRS || '';
            response.companyName = html_entities_1.XmlEntities.decode(dataKrs.dane.dzial1.danePodmiotu.nazwa || '').replace(/\s+/g, ' ').trim();
            response.startDate = dataGus.dane.praw_dataRozpoczeciaDzialalnosci || '';
            response.endDate = dataGus.dane.praw_dataZakonczeniaDzialalnosci || '';
            response.status = dataGus.dane.praw_dataZakonczeniaDzialalnosci ? 'WYKREŚLONY' : 'AKTYWNY';
            response.phone = dataGus.dane.praw_numerTelefonu || '';
            response.email = dataGus.dane.praw_adresEmail || '';
            response.website = dataKrs.dane.dzial1.siedzibaIAdres.adresStronyInternetowej || '';
            response.pkd = dataGus.dane.pkd;
            response.legalForm = new ResponseLegalForm_1.ResponseLegalForm();
            response.legalForm.basic = dataGus.dane.praw_podstawowaFormaPrawna_Symbol || '';
            response.legalForm.specific = dataGus.dane.praw_szczegolnaFormaPrawna_Symbol || '';
            response.businessAddress = new ResponseAddressData_1.ResponseAddressData();
            response.businessAddress.town = dataKrs.dane.dzial1.siedzibaIAdres.adres.miejscowosc || '';
            response.businessAddress.zipCode = dataKrs.dane.dzial1.siedzibaIAdres.adres.kodPocztowy || '';
            response.businessAddress.street = dataKrs.dane.dzial1.siedzibaIAdres.adres.ulica || '';
            response.businessAddress.houseNo = dataKrs.dane.dzial1.siedzibaIAdres.adres.nrDomu || '';
            response.businessAddress.doorNo = dataKrs.dane.dzial1.siedzibaIAdres.adres.nrLokalu || '';
            response.businessAddress.post = dataKrs.dane.dzial1.siedzibaIAdres.adres.poczta || '';
            response.businessAddress.community = dataKrs.dane.dzial1.siedzibaIAdres.siedziba.gmina || '';
            response.businessAddress.county = dataKrs.dane.dzial1.siedzibaIAdres.siedziba.powiat || '';
            response.businessAddress.province = dataKrs.dane.dzial1.siedzibaIAdres.siedziba.wojewodztwo || '';
            response.correspondenceAddress = new ResponseAddressData_1.ResponseAddressData();
            response.correspondenceAddress.town = '';
            response.correspondenceAddress.zipCode = '';
            response.correspondenceAddress.street = '';
            response.correspondenceAddress.houseNo = '';
            response.correspondenceAddress.doorNo = '';
            response.correspondenceAddress.post = '';
            response.correspondenceAddress.community = '';
            response.correspondenceAddress.county = '';
            response.correspondenceAddress.province = '';
            return response;
        });
    }
}
exports.KrsApiClient = KrsApiClient;
function moment(arg0) {
    throw new Error('Function not implemented.');
}
