"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CeidgReport = void 0;
class Adres {
    constructor(adres) {
        this.ulica = adres.ulica;
        this.budynek = adres.budynek;
        this.lokal = adres.lokal;
        this.miasto = adres.miasto;
        this.wojewodztwo = adres.wojewodztwo;
        this.powiat = adres.powiat;
        this.gmina = adres.gmina;
        this.kraj = adres.kraj;
        this.kod = adres.kod;
        this.terc = adres.terc;
        this.simc = adres.simc;
        this.ulic = adres.ulic;
    }
}
class Wlasciciel {
    constructor(wlasciciel) {
        this.imie = wlasciciel.imie;
        this.nazwisko = wlasciciel.nazwisko;
        this.nip = wlasciciel.nip;
        this.regon = wlasciciel.regon;
    }
}
class Obywatelstwo {
    constructor(obywatelstwo) {
        this.symbol = obywatelstwo.symbol;
        this.kraj = obywatelstwo.kraj;
    }
}
class Firma {
    constructor(firma) {
        this.id = firma.id;
        this.nazwa = firma.nazwa;
        this.adresDzialalnosci = firma.adresDzialalnosci ? new Adres(firma.adresDzialalnosci) : undefined;
        this.adresKorespondencyjny = new Adres(firma.adresKorespondencyjny);
        this.wlasciciel = new Wlasciciel(firma.wlasciciel);
        this.obywatelstwa = firma.obywatelstwa.map(o => new Obywatelstwo(o));
        this.pkd = firma.pkd;
        this.pkdGlowny = firma.pkdGlowny;
        this.dataRozpoczecia = firma.dataRozpoczecia;
        this.dataWykreslenia = firma.dataWykreslenia;
        this.status = firma.status;
        this.numerStatusu = firma.numerStatusu;
        this.email = firma.email;
        this.www = firma.www;
        this.wspolnoscMajatkowa = firma.wspolnoscMajatkowa;
        this.podstawyPrawneWykreslenia = firma.podstawyPrawneWykreslenia;
        this.link = firma.link;
    }
}
// Klasa główna reprezentująca całość danych
class CeidgReport {
    constructor(data) {
        if (data && Array.isArray(data.firma)) {
            const foundFirma = data.firma.find(item => item.status === 'AKTYWNY');
            if (foundFirma) {
                this.firma = foundFirma;
            }
            else {
                const dataFirma = this.findActiveOrNewestFirma(data.firma);
                if (dataFirma) {
                    this.firma = dataFirma;
                }
            }
        }
        else {
            console.error('Dane są niezdefiniowane lub firma nie jest tablicą.');
        }
    }
    findActiveOrNewestFirma(data) {
        console.log(data);
        // 1. Szukamy firmy ze statusem "AKTYWNY"
        const activeFirma = data.find((firma) => firma.status.toLocaleUpperCase() === 'AKTYWNY');
        // 2. Jeśli taka firma istnieje, zwracamy ją
        if (activeFirma) {
            return activeFirma;
        }
        return data.reduce((newest, current) => {
            return new Date(current.dataRozpoczecia) > new Date(newest.dataRozpoczecia) ? current : newest;
        }, data[0]);
    }
}
exports.CeidgReport = CeidgReport;
