"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GusModel = void 0;
const fast_xml_parser_1 = require("fast-xml-parser");
const ZalogujRequest_1 = require("./GUS/ZalogujRequest");
const SimpleReportResponse_1 = require("./GUS/SimpleReportResponse");
class GusModel {
    constructor(apiKey) {
        if (apiKey) {
            this.apiKey = apiKey;
            this.requestSid = new ZalogujRequest_1.ZalogujRequest(apiKey);
            // console.log(this.requestSid.toXML());
        }
    }
    static fromJson(data) {
        const envelopeRegex = /<s:Envelope[\s\S]*?<\/s:Envelope>/;
        const match = data.match(envelopeRegex);
        if (!match) {
            console.log('No <s:Envelope> found.');
            return undefined;
        }
        // Opcje parsera
        const options = {
            ignoreAttributes: false, // Nie ignorujemy atrybutów
            attributeNamePrefix: 'praw_', // Bez prefiksów dla atrybutów
            parseTagValue: false, // Wyłączamy automatyczne parsowanie wartości tagów
        };
        const envelope = match[0];
        // Walidacja XML
        const isValid = fast_xml_parser_1.XMLValidator.validate(envelope);
        if (!isValid) {
            console.warn('Invalid XML format. The <s:Envelope> element might be malformed.');
        }
        else {
            const parser = new fast_xml_parser_1.XMLParser(options);
            // Parsowanie i walidacja tylko <s:Envelope>
            const result = parser.parse(envelope);
            // Sprawdzenie, czy <s:Envelope> jest obecny
            if (result['s:Envelope']) {
                const gusSimpleData = result['s:Envelope']['s:Body']['DanePobierzPelnyRaportResponse']['DanePobierzPelnyRaportResult'];
                const resultA = parser.parse(gusSimpleData);
                if (resultA) {
                    return resultA.root;
                }
            }
            else {
                console.warn('The <s:Envelope> element is missing.');
            }
        }
        return undefined;
    }
    static fromJsonPkd(data) {
        const envelopeRegex = /<s:Envelope[\s\S]*?<\/s:Envelope>/;
        const match = data.match(envelopeRegex);
        if (!match) {
            console.log('No <s:Envelope> found.');
            return undefined;
        }
        // Opcje parsera
        const options = {
            ignoreAttributes: false, // Nie ignorujemy atrybutów
            attributeNamePrefix: 'praw_', // Bez prefiksów dla atrybutów
            parseTagValue: false, // Wyłączamy automatyczne parsowanie wartości tagów
        };
        const envelope = match[0];
        // Walidacja XML
        const isValid = fast_xml_parser_1.XMLValidator.validate(envelope);
        if (!isValid) {
            console.warn('Invalid XML format. The <s:Envelope> element might be malformed.');
        }
        else {
            const parser = new fast_xml_parser_1.XMLParser(options);
            // Parsowanie i walidacja tylko <s:Envelope>
            const result = parser.parse(envelope);
            // Sprawdzenie, czy <s:Envelope> jest obecny
            if (result['s:Envelope']) {
                const gusSimpleData = result['s:Envelope']['s:Body']['DanePobierzPelnyRaportResponse']['DanePobierzPelnyRaportResult'];
                const resultA = parser.parse(gusSimpleData);
                if (resultA) {
                    let pkdCodes = [];
                    if (Array.isArray(resultA.root.dane)) {
                        pkdCodes = resultA.root.dane.map((item) => item.praw_pkdKod);
                    }
                    else if (resultA.root.dane.ErrorCode) {
                        // nic nie rób - podmiot wykreslony
                    }
                    else {
                        pkdCodes.push(resultA.root.dane.praw_pkdKod || '');
                    }
                    // const pkdCodes = resultA.root.dane.map((item: { praw_pkdKod: any; }) => item.praw_pkdKod);
                    // console.log(pkdCodes);
                    return pkdCodes;
                }
            }
            else {
                console.warn('The <s:Envelope> element is missing.');
            }
        }
        return undefined;
    }
    static sidFromJson(data) {
        const envelopeRegex = /<s:Envelope[\s\S]*?<\/s:Envelope>/;
        const match = data.match(envelopeRegex);
        if (!match) {
            console.log('No <s:Envelope> found.');
            return '';
        }
        // Opcje parsera
        const options = {
            ignoreAttributes: false,
            parseNodeValue: true,
            trimValues: true,
            attributeNamePrefix: '',
        };
        const envelope = match[0];
        const parser = new fast_xml_parser_1.XMLParser(options);
        // Walidacja XML
        const isValid = fast_xml_parser_1.XMLValidator.validate(envelope);
        if (!isValid) {
            console.warn('Invalid XML format. The <s:Envelope> element might be malformed.');
        }
        else {
            // Parsowanie i walidacja tylko <s:Envelope>
            const result = parser.parse(envelope);
            // Sprawdzenie, czy <s:Envelope> jest obecny
            if (result['s:Envelope']) {
                const gusSid = result['s:Envelope']['s:Body'].ZalogujResponse.ZalogujResult;
                return gusSid;
            }
            else {
                console.warn('The <s:Envelope> element is missing.');
            }
        }
        return '';
    }
    static regonFromJson(data) {
        const envelopeRegex = /<s:Envelope[\s\S]*?<\/s:Envelope>/;
        const match = data.match(envelopeRegex);
        if (!match) {
            // console.log('No <s:Envelope> found.');
            return undefined;
        }
        // Opcje parsera
        const options = {
            ignoreAttributes: false, // Nie ignorujemy atrybutów
            attributeNamePrefix: '', // Bez prefiksów dla atrybutów
            parseTagValue: false, // Wyłączamy automatyczne parsowanie wartości tagów
        };
        const envelope = match[0];
        // Walidacja XML
        const isValid = fast_xml_parser_1.XMLValidator.validate(envelope);
        if (!isValid) {
            console.warn('Invalid XML format. The <s:Envelope> element might be malformed.');
        }
        else {
            const parser = new fast_xml_parser_1.XMLParser(options);
            // Parsowanie i walidacja tylko <s:Envelope>
            const result = parser.parse(envelope);
            // Sprawdzenie, czy <s:Envelope> jest obecny
            if (result['s:Envelope']) {
                // console.log(result);
                const gusSimpleData = result['s:Envelope']['s:Body']['DaneSzukajPodmiotyResponse']['DaneSzukajPodmiotyResult'];
                const resultA = parser.parse(gusSimpleData);
                if (resultA) {
                    // return resultA.root as SimpleReportResponse;
                    return new SimpleReportResponse_1.SimpleReportResponse(resultA.root.dane);
                }
            }
            else {
                console.warn('The <s:Envelope> element is missing.');
            }
        }
        return undefined;
    }
}
exports.GusModel = GusModel;
